# gitlab-downloader 


<p align="left">
         <a href="https://pypi.python.org/pypi/prefect-gitlab/" alt="PyPI version">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/gitlab-projects-downloader?color=26272B&labelColor=090422"></a>
</p>

### Motivation
Every day someone ask me to export something from X and import into Y  from gitlab; so...

## ENV 
```dotenv
GITLAB_URL=""
ACCESS_TOKEN=""
EXPORT_FOLDER="./gitlab_exports"
```

## Installation

You can install the package via `PyPi`:

```bash
pip install gitlab-projects-downloader
```


🍕 ENJOY 